package com.zjsgfa.project.zjsgfa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zjsgfa.project.zjsgfa.mapper.SjFdsgcsZjfxztMapper;
import com.zjsgfa.project.zjsgfa.domain.SjFdsgcsZjfxzt;
import com.zjsgfa.project.zjsgfa.service.ISjFdsgcsZjfxztService;

/**
 * 分段施工措施-专家分析钻头Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-12-10
 */
@Service
public class SjFdsgcsZjfxztServiceImpl implements ISjFdsgcsZjfxztService 
{
    @Autowired
    private SjFdsgcsZjfxztMapper sjFdsgcsZjfxztMapper;

    /**
     * 查询分段施工措施-专家分析钻头
     * 
     * @param id 分段施工措施-专家分析钻头主键
     * @return 分段施工措施-专家分析钻头
     */
    @Override
    public SjFdsgcsZjfxzt selectSjFdsgcsZjfxztById(Long id)
    {
        return sjFdsgcsZjfxztMapper.selectSjFdsgcsZjfxztById(id);
    }

    /**
     * 查询分段施工措施-专家分析钻头列表
     * 
     * @param sjFdsgcsZjfxzt 分段施工措施-专家分析钻头
     * @return 分段施工措施-专家分析钻头
     */
    @Override
    public List<SjFdsgcsZjfxzt> selectSjFdsgcsZjfxztList(SjFdsgcsZjfxzt sjFdsgcsZjfxzt)
    {
        return sjFdsgcsZjfxztMapper.selectSjFdsgcsZjfxztList(sjFdsgcsZjfxzt);
    }

    /**
     * 新增分段施工措施-专家分析钻头
     * 
     * @param sjFdsgcsZjfxzt 分段施工措施-专家分析钻头
     * @return 结果
     */
    @Override
    public int insertSjFdsgcsZjfxzt(SjFdsgcsZjfxzt sjFdsgcsZjfxzt)
    {
        return sjFdsgcsZjfxztMapper.insertSjFdsgcsZjfxzt(sjFdsgcsZjfxzt);
    }

    /**
     * 修改分段施工措施-专家分析钻头
     * 
     * @param sjFdsgcsZjfxzt 分段施工措施-专家分析钻头
     * @return 结果
     */
    @Override
    public int updateSjFdsgcsZjfxzt(SjFdsgcsZjfxzt sjFdsgcsZjfxzt)
    {
        return sjFdsgcsZjfxztMapper.updateSjFdsgcsZjfxzt(sjFdsgcsZjfxzt);
    }

    /**
     * 批量删除分段施工措施-专家分析钻头
     * 
     * @param ids 需要删除的分段施工措施-专家分析钻头主键
     * @return 结果
     */
    @Override
    public int deleteSjFdsgcsZjfxztByIds(Long[] ids)
    {
        return sjFdsgcsZjfxztMapper.deleteSjFdsgcsZjfxztByIds(ids);
    }

    /**
     * 删除分段施工措施-专家分析钻头信息
     * 
     * @param id 分段施工措施-专家分析钻头主键
     * @return 结果
     */
    @Override
    public int deleteSjFdsgcsZjfxztById(Long id)
    {
        return sjFdsgcsZjfxztMapper.deleteSjFdsgcsZjfxztById(id);
    }
}
